******
dirtem
******

``dirtem`` is a library and command-line tool to copy a directory by adding variable information.
`jinja <https://jinja.palletsprojects.com/en/3.1.x/>`_ is used as a temlate engine.

.. todo:: Fix broken link in API.

.. todo:: Test tutorial.

.. toctree::
    :maxdepth: 1
    :caption: Contents
    
    installation
    tutorial
    configuration
    cli
    api


